# nw-solution-architect

Use for DESIGN wave - collaborates with user to define system architecture, component boundaries, technology selection, and creates architecture documents with business value focus. Hands off to acceptance-designer.

**Wave:** DESIGN
**Model:** inherit
**Max turns:** 50
**Tools:** Read, Write, Edit, Glob, Grep, Task

## Commands

- [`/nw:deliver`](../commands/index.md)
- [`/nw:design`](../commands/index.md)
- [`/nw:diagram`](../commands/index.md)
- [`/nw:discuss`](../commands/index.md)
- [`/nw:finalize`](../commands/index.md)
- [`/nw:review`](../commands/index.md)
- [`/nw:roadmap`](../commands/index.md)

## Skills

- [architecture-patterns](../../../nWave/skills/solution-architect/architecture-patterns.md) — Comprehensive architecture patterns, methodologies, quality frameworks, and evaluation methods for solution architects. Load when designing system architecture or selecting patterns.
- [critique-dimensions](../../../nWave/skills/acceptance-designer/critique-dimensions.md) — Review dimensions for acceptance test quality - happy path bias, GWT compliance, business language purity, coverage completeness, walking skeleton user-centricity, and priority validation
- [critique-dimensions](../../../nWave/skills/agent-builder/critique-dimensions.md) — Review dimensions for validating agent quality - template compliance, safety, testing, and priority validation
- [critique-dimensions](../../../nWave/skills/platform-architect-reviewer/critique-dimensions.md) — Platform design review critique dimensions and severity levels. Load when reviewing CI/CD pipelines, infrastructure, deployment strategies, observability, or security designs.
- [critique-dimensions](../../../nWave/skills/researcher-reviewer/critique-dimensions.md) — Critique dimensions and scoring for research document reviews
- [critique-dimensions](../../../nWave/skills/solution-architect/critique-dimensions.md) — Architecture quality critique dimensions for peer review. Load when invoking solution-architect-reviewer or performing self-review of architecture documents.
- [roadmap-design](../../../nWave/skills/solution-architect/roadmap-design.md) — Roadmap concision rules, step decomposition efficiency, AC abstraction guidelines, and step-to-scenario mapping. Load when creating implementation roadmaps.
- [stress-analysis](../../../nWave/skills/solution-architect/stress-analysis.md) — Advanced architecture stress analysis methodology for designing systems that survive unknown stresses. Load when --residuality flag is used or when designing high-uncertainty, mission-critical systems.
